@@ -2,16 +2,22 @@ import logging
 
 import click
 
+import changes
 from changes import attributes, config, probe, version
 from changes.changelog import generate_changelog
 from changes.flow import perform_release
-from changes.packaging import install_package, upload_package, install_from_pypi
+from changes.packaging import build_distributions, install_package, upload_package, install_from_pypi
 from changes.vcs import tag_and_push
 from changes.version import increment_version
 
 log = logging.getLogger(__name__)
 
 
+def print_version(ctx, param, value):
+    if not value or ctx.resilient_parsing:
+        return
+    click.echo('changes %s' % changes.__version__)
+    ctx.exit()
 
 
 @click.group()
@@ -24,6 +30,8 @@ log = logging.getLogger(__name__)
 @click.option('-m', '--minor', is_flag=True, help='Minor-level version increment.')
 @click.option('-M', '--major', is_flag=True, help='Minor-level version increment.')
 @click.option('--version-prefix', help='Specify a prefix for version number tags.')
+@click.option('--version', is_flag=True, callback=print_version,
+              expose_value=False, is_eager=True)
 @click.pass_context
 def main(context, module_name, dry_run, debug, no_input, requirements, patch, minor, major, version_prefix):
     """Ch-ch-changes"""
@@ -38,7 +46,9 @@ def main(context, module_name, dry_run, debug, no_input, requirements, patch, mi
 
     current_version = version.current_version(module_name)
     repo_url = attributes.extract_attribute(module_name, '__url__')
-    context.obj = config.Changes(module_name, dry_run, debug, no_input, requirements, new_version, current_version, repo_url, version_prefix)
+    context.obj = config.CLI(module_name, dry_run, debug, no_input,
+                             requirements, new_version, current_version,
+                             repo_url, version_prefix)
 
     probe.probe_project(context.obj)
 
@@ -57,6 +67,13 @@ def bump_version(context):
     increment_version(context.obj)
 
 
+@click.command()
+@click.pass_context
+def build(context):
+    """Attempts to build the sdist and wheel."""
+    build_distributions(context.obj)
+
+
 @click.command()
 @click.option('--test-command', help='Command to use to test the newly installed package.')
 @click.pass_context
@@ -90,6 +107,7 @@ def tag(context):
     """Tags your git repo with the new version number"""
     tag_and_push(context.obj)
 
+
 @click.command()
 @click.option('--skip-changelog', is_flag=True, help='For the release task: should the changelog be generated and committed?')
 @click.pass_context
@@ -101,6 +119,7 @@ def release(context, skip_changelog):
 
 main.add_command(changelog)
 main.add_command(bump_version)
+main.add_command(build)
 main.add_command(install)
 main.add_command(upload)
 main.add_command(pypi)
