@@ -1,3 +1,9 @@
+import contextlib
+import tempfile
+
+from path import path
+
+
 def extract(dictionary, keys):
     """
     Extract only the specified keys from a dict
@@ -12,6 +18,10 @@ def extract(dictionary, keys):
 
 
 def extract_arguments(arguments, long_keys, key_prefix='--'):
+    """
+    :param arguments: dict of command line arguments
+
+    """
     long_arguments = extract(
         arguments,
         long_keys,
@@ -20,3 +30,12 @@ def extract_arguments(arguments, long_keys, key_prefix='--'):
         (key.replace(key_prefix, ''), value)
         for key, value in long_arguments.items()
     ])
+
+
+@contextlib.contextmanager
+def mktmpdir():
+    tmp_dir = tempfile.mkdtemp()
+    try:
+        yield tmp_dir
+    finally:
+        path(tmp_dir).rmtree(path(tmp_dir))
