@@ -1,3 +1,6 @@
+from __future__ import (absolute_import, division,
+                        print_function, unicode_literals)
+
 import logging
 
 import click
@@ -25,13 +28,10 @@ def get_new_version(module_name, current_version, no_input,
     if no_input:
         new_version = proposed_new_version
     else:
-        new_version = raw_input(
-            'What is the release version for "%s" '
-            '[Default: %s]: ' % (
-                module_name, proposed_new_version
-            )
-        ) or proposed_new_version
-
+        new_version = click.prompt(
+            'What is the release version for "{0}" '.format(module_name),
+            default=proposed_new_version
+        )
     return new_version.strip()
 
 
